@@ -1,6 +1,6 @@
 package Bio::MLST::FilterAlleles;
 # ABSTRACT: Filter Alleles
-$Bio::MLST::FilterAlleles::VERSION = '2.1.1630713';
+$Bio::MLST::FilterAlleles::VERSION = '2.1.1630714';
 
 use strict;
 use warnings;
@@ -26,7 +26,7 @@ my @allele_blacklist = (
 sub is_metadata
 {
   my ($column_heading) = @_;
-  return $column_heading ~~ @allele_blacklist;
+  return grep( /^$column_heading$/, @allele_blacklist );
 }
 
 sub only_keep_alleles
@@ -53,7 +53,7 @@ Bio::MLST::FilterAlleles - Filter Alleles
 
 =head1 VERSION
 
-version 2.1.1630713
+version 2.1.1630714
 
 =head1 SYNOPSIS
 
